# Code of Conduct

## Our Pledge

We as members, contributors, and leaders pledge to make participation in our community a harassment-free experience for everyone, regardless of age, body size, visible or invisible disability, ethnicity, sex characteristics, gender identity and expression, level of experience, education, socio-economic status, nationality, personal appearance, race, religion, or sexual identity and orientation.

We pledge to act and interact in ways that contribute to an open, welcoming, diverse, inclusive, and healthy community.

## Our Standards

Examples of behavior that contributes to a positive environment for our community include:

### 🤝 Positive Behaviors
- Demonstrating empathy and kindness toward other people
- Being respectful of differing opinions, viewpoints, and experiences
- Giving and gracefully accepting constructive feedback
- Accepting responsibility and apologizing to those affected by our mistakes, and learning from the experience
- Focusing on what is best not just for us as individuals, but for the overall community
- Using welcoming and inclusive language
- Being patient with newcomers and those learning
- Recognizing and crediting the contributions of others

### 🏥 Healthcare-Specific Standards
- Maintaining the highest standards of clinical accuracy and patient safety
- Respecting patient privacy and confidentiality in all discussions
- Ensuring healthcare information shared is evidence-based and appropriate
- Being sensitive to cultural differences in healthcare practices
- Prioritizing patient welfare in all technical decisions

### 💻 Technical Standards
- Writing clear, maintainable, and well-documented code
- Providing constructive code reviews focused on improvement
- Sharing knowledge and helping others learn
- Following established coding standards and best practices
- Being open to learning new approaches and technologies

## Unacceptable Behavior

Examples of unacceptable behavior include:

### 🚫 General Violations
- The use of sexualized language or imagery, and sexual attention or advances of any kind
- Trolling, insulting or derogatory comments, and personal or political attacks
- Public or private harassment
- Publishing others' private information, such as a physical or email address, without their explicit permission
- Other conduct which could reasonably be considered inappropriate in a professional setting

### 🚫 Healthcare-Specific Violations
- Sharing actual patient data or information without proper authorization
- Providing medical advice or clinical recommendations outside of appropriate contexts
- Misrepresenting clinical credentials or healthcare expertise
- Promoting unproven or harmful medical practices
- Violating healthcare privacy regulations (HIPAA, GDPR, etc.)

### 🚫 Technical Violations
- Deliberately introducing security vulnerabilities or malicious code
- Plagiarizing code or documentation without proper attribution
- Disrupting community infrastructure or tools
- Sharing credentials, API keys, or other sensitive technical information

## Community Guidelines

### 💬 Communication Guidelines
- **Be Kind**: Treat everyone with respect and consideration
- **Be Clear**: Communicate clearly and constructively
- **Be Patient**: Remember that people have different levels of experience
- **Be Inclusive**: Use language that welcomes all community members
- **Be Professional**: Maintain professional standards in all interactions

### 🏥 Healthcare Context Guidelines
- **Clinical Accuracy**: Ensure all healthcare information is accurate and evidence-based
- **Privacy First**: Never share real patient data or protected health information
- **Cultural Sensitivity**: Respect diverse healthcare practices and cultural approaches
- **Safety Focus**: Prioritize patient safety in all technical decisions
- **Regulatory Awareness**: Consider healthcare regulations and compliance requirements

### 🔬 Research and Development Guidelines
- **Evidence-Based**: Base technical decisions on solid evidence and research
- **Open Science**: Share knowledge and research findings openly when appropriate
- **Collaboration**: Work together to advance healthcare AI capabilities
- **Quality Focus**: Maintain high standards for code quality and testing
- **Innovation**: Encourage creative solutions while maintaining safety standards

## Enforcement Responsibilities

Community leaders are responsible for clarifying and enforcing our standards of acceptable behavior and will take appropriate and fair corrective action in response to any behavior that they deem inappropriate, threatening, offensive, or harmful.

Community leaders have the right and responsibility to remove, edit, or reject comments, commits, code, wiki edits, issues, and other contributions that are not aligned to this Code of Conduct, and will communicate reasons for moderation decisions when appropriate.

## Scope

This Code of Conduct applies within all community spaces, and also applies when an individual is officially representing the community in public spaces. Examples of representing our community include using an official e-mail address, posting via an official social media account, or acting as an appointed representative at an online or offline event.

### 🌍 Community Spaces
- GitHub repositories and discussions
- Discord server and channels
- Community forums and mailing lists
- Conference presentations and workshops
- Social media interactions related to HACS

## Reporting Guidelines

### 📧 How to Report
Instances of abusive, harassing, or otherwise unacceptable behavior may be reported to the community leaders responsible for enforcement at:

- **Email**: conduct@hacs.dev
- **GitHub**: Private message to maintainers
- **Discord**: Direct message to moderators

### 🔒 Privacy and Confidentiality
All complaints will be reviewed and investigated promptly and fairly. All community leaders are obligated to respect the privacy and security of the reporter of any incident.

### ⏱️ Response Timeline
- **Acknowledgment**: Within 24 hours
- **Initial Response**: Within 72 hours
- **Resolution**: Within 2 weeks (complex cases may take longer)

## Enforcement Guidelines

Community leaders will follow these Community Impact Guidelines in determining the consequences for any action they deem in violation of this Code of Conduct:

### 1. Correction
**Community Impact**: Use of inappropriate language or other behavior deemed unprofessional or unwelcome in the community.

**Consequence**: A private, written warning from community leaders, providing clarity around the nature of the violation and an explanation of why the behavior was inappropriate. A public apology may be requested.

### 2. Warning
**Community Impact**: A violation through a single incident or series of actions.

**Consequence**: A warning with consequences for continued behavior. No interaction with the people involved, including unsolicited interaction with those enforcing the Code of Conduct, for a specified period of time. This includes avoiding interactions in community spaces as well as external channels like social media. Violating these terms may lead to a temporary or permanent ban.

### 3. Temporary Ban
**Community Impact**: A serious violation of community standards, including sustained inappropriate behavior.

**Consequence**: A temporary ban from any sort of interaction or public communication with the community for a specified period of time. No public or private interaction with the people involved, including unsolicited interaction with those enforcing the Code of Conduct, is allowed during this period. Violating these terms may lead to a permanent ban.

### 4. Permanent Ban
**Community Impact**: Demonstrating a pattern of violation of community standards, including sustained inappropriate behavior, harassment of an individual, or aggression toward or disparagement of classes of individuals.

**Consequence**: A permanent ban from any sort of public interaction within the community.

## Healthcare-Specific Enforcement

### 🏥 Clinical Safety Violations
Violations that could impact patient safety or clinical accuracy will be treated with heightened seriousness and may result in immediate temporary bans while the issue is investigated.

### 🔒 Privacy Violations
Any sharing of actual patient data or protected health information will result in immediate removal of the content and may result in permanent ban from the community.

### 📋 Regulatory Compliance
Community leaders will work to ensure all community activities comply with relevant healthcare regulations and will take appropriate action when violations are identified.

## Appeals Process

### 📝 How to Appeal
Community members who believe they have been unfairly penalized may appeal the decision by:

1. Sending an email to appeals@hacs.dev within 30 days
2. Providing a clear explanation of why they believe the decision was unfair
3. Including any relevant evidence or context

### 🔍 Appeal Review
Appeals will be reviewed by a panel of community leaders not involved in the original decision. The appeal process aims to be fair, transparent, and timely.

## Positive Recognition

### 🏆 Community Recognition
We believe in recognizing positive contributions to our community:

- **Helpful Contributor**: For those who consistently help others
- **Clinical Expert**: For healthcare professionals who provide valuable domain expertise
- **Technical Mentor**: For those who help others learn and grow technically
- **Community Builder**: For those who help grow and strengthen our community

## Resources

### 📚 Additional Resources
- [Contributing Guidelines](docs/contributing/guidelines.md)
- [Technical Documentation](docs/README.md)
- [Healthcare Compliance Guide](docs/reference/compliance.md)
- [Community Discord](https://discord.gg/hacs)

### 🆘 Support Resources
If you're experiencing harassment or need support:
- **Crisis Text Line**: Text HOME to 741741
- **National Suicide Prevention Lifeline**: 988
- **SAMHSA National Helpline**: 1-800-662-HELP (4357)

## Attribution

This Code of Conduct is adapted from the [Contributor Covenant][homepage], version 2.0, available at https://www.contributor-covenant.org/version/2/0/code_of_conduct.html.

Community Impact Guidelines were inspired by [Mozilla's code of conduct enforcement ladder](https://github.com/mozilla/diversity).

For answers to common questions about this code of conduct, see the FAQ at https://www.contributor-covenant.org/faq. Translations are available at https://www.contributor-covenant.org/translations.

[homepage]: https://www.contributor-covenant.org

---

## Contact

For questions about this Code of Conduct, please contact:
- **Email**: conduct@hacs.dev
- **Community Leaders**: Available via GitHub and Discord

*This Code of Conduct is a living document and may be updated as our community grows and evolves.* 